#include <stdio.h>
#include <stdlib.h>
#include <string.h>

typedef struct {
    char name[64];
    int wins;
    int losses;
    int score;
} player;

/* find a player from the array */
int find(char* name, player* roster, int size) {
    for (int i = 0; i < size; i++) {
        if (strcmp(roster[i].name, name) == 0) {
            return i;
        }
    }

    return -1;
}

/* find the score for a player based on wins and losses */
void calculate_scores(player* roster, int players) {
    for (int i = 0; i < players; i++) {
        roster[i].score = roster[i].wins * 2 - roster[i].losses;
    }
}

/* comparison function for use with qsort -
 * I probably could have found a cleaner way to do this */
int compare(const void* ap, const void* bp) {
    player* a = (player*) ap;
    player* b = (player*) bp;

    /* if only one has 0 losses, prefer it */
    if (a->losses == 0 && b->losses > 0) {
        return -1;
    }
    if (a->losses > 0 && b->losses == 0) {
        return 1;
    }

    /* if they both have 0 losses, prefer more wins */
    if (a->losses == 0 && b->losses == 0) {
        if (a->wins > b->wins) {
            return -1;
        }
        if (a->wins < b->wins) {
            return 1;
        }
        /* if same, go by names */
        if (a->wins == b->wins) {
            return strcmp(a->name, b->name);
        }
    }


    /* if only one has 0 wins, it loses */
    if (a->wins == 0 && b->wins > 0) {
        return 1;
    }
    if (a->wins > 0 && b->wins == 0) {
        return -1;
    }

    /* if they both have 0 wins, prefer fewer losses */
    if (a->wins == 0 && b->wins == 0) {
        if (a->losses > b->losses) {
            return 1;
        }
        if (a->losses < b->losses) {
            return -1;
        }
        /* if same, go by names */
        if (a->losses == b->losses) {
            return strcmp(a->name, b->name);
        }
    }

    /* now go by the score they have */
    if (a->score > b->score) {
        return -1;
    }

    if (a->score < b->score) {
        return 1;
    }

    /* go alphabetically */
    return strcmp(a->name, b->name);
}

int main() {
    /* how many players are we wanking */
    int players;
    scanf("%d\n", &players);

    /* read their names */
    player* roster = malloc(players * sizeof(player));
    for (int i = 0; i < players; i++) {
        scanf("%[^\n]\n", roster[i].name);
        roster[i].wins = 0;
        roster[i].losses = 0;
        roster[i].score = 0;
    }

    /* go through the match list */
    int matches;    
    scanf("%d\n", &matches);
    for (int i = 0; i < matches; i++) {
        char winner[64], loser[64];
        scanf("%s beats %[^.].\n", winner, loser);
        roster[find(winner, roster, players)].wins++;
        roster[find(loser, roster, players)].losses++;
    }

    /* calculate each of their scores */
    calculate_scores(roster, players);

    /* sort the list with qsort w/ custom comparator */
    qsort(roster, players, sizeof(player), &compare);

    /* now go through and print all of the players in order */
    for (int i = 0; i < players; i++) {
        /* skip ones w/ no matches */
        if (roster[i].wins == 0 && roster[i].losses == 0) continue;

        /* print the line */
        printf("%s: %d-%d\n", roster[i].name, roster[i].wins, roster[i].losses);
    }

    /* clean up memory */
    free(roster);

    return 0;
}

