#include <stdio.h>
#include <stdlib.h>
#include <string.h>

/* global to reduce passing parameters (get is called a lot) */
int rows, cols;
char** level;

/* this function retrieves a char from the level, or returns 0 if out of bounds */
char get(int row, int col) {
    if (row < 0 || col < 0 || row >= rows || col >= cols) {
        return 0;
    }

    return level[row][col];
}

/* a struct for putting positions into an array */
typedef struct {
    int row, col;
} position;

/* this function searches for blocks that mario can get to from here */
void search_forward(int rows, int cols, position pos, char** level, position* possibilities, int* num_possible, int height) {
    /* search forward for each column */
    for (int col = pos.col + 1; pos.col < cols; col++) {

        /* search from height down for landing spots */
        for (int row = height; row < rows; row++) {

            /* if thing above this (where we are) is solid ground, we're done */
            if (get(row - 1, col) == '#') {
                return;
            }

            /* if this one here is solid ground, add it */
            if (get(row, col) == '#' && get(row - 1, col) != '#') {
                /* search to see if it exists */
                int exists = 0;
                for (int i = 0; i < *num_possible; i++) {
                    if (possibilities[i].row == row && possibilities[i].col == col) {
                        exists = 1;
                    }
                }

                /* if not, chuck it in */
                if (!exists) {
                    possibilities[*num_possible].row = row;
                    possibilities[*num_possible].col = col;
                    *num_possible += 1;
                }

                /* we can't do anything else in this column, go to next one */
                break;
            }
        }

        /* height goes down each column forward */
        height++;

        /* if it's bigger than the board, we are dead if we go any more */
        if (height >= rows) {
            break;
        }
    }
}

int main() {
    /* read the level size */
    char line[100];
    fgets(line, 100, stdin);
    sscanf(line, "%d", &rows);
    fgets(line, 100, stdin);
    sscanf(line, "%d", &cols);

    /* read the lines */
    level = malloc(rows * sizeof(char*));
    for (int i = 0; i < rows; i++) {
        level[i] = malloc((cols + 2) * sizeof(char));
        fgets(level[i], cols + 2, stdin);
        level[i][cols] = '\0';
    }

    /* we maintain a list of places he could be at based on his motions */
    position* possibilities = malloc(rows * cols * sizeof(position));

    /* the only one initially is the beginning position */
    int num_possible = 1;
    possibilities[0].row = rows - 1;
    possibilities[0].col = 0;

    /* keep going while we can and are not done */
    int complete = 0;
    while (num_possible) {
        /* tackle the next one */
        position current = possibilities[0];
        for (int i = 0; i < (num_possible - 1); i++) {
            possibilities[i] = possibilities[i + 1];
        }
        num_possible--;

        /* if this is the last column, we are done! */
        if (current.col == (cols - 1)) {
            complete = 1;
            break;
        }

        /* if mario's head is clear he can jump 2 up, otherwise he can't jump */
        int height = get(current.row - 1, current.col) != '#' ? current.row - 2 : current.row;

        /* try to do this for each of the jump heights we can do */
        for (int h = height; h <= current.row; h++) {
            /* search where we can get to from here, adding them into the list to search */
            search_forward(rows, cols, current, level, possibilities, &num_possible, h);
        }
    }

    /* check if we won or not */
    if (complete) {
        printf("Mario can make it!\n");
    } else {
        printf("Mario cannot make it!\n");
    }

    /* clean things up */
    for (int i = 0; i < rows; i++) {
        free(level[i]);
    }
    free(level);
    free(possibilities);
    return 0;
}

