#include <stdio.h>
#include <math.h>
#include <stdlib.h>
#include <string.h>

/* this program solves the problem by trying all of the possible shots down
 * to some granularity - the X_GRANULARITY is the amount we increment X by
 * in our search, the THETA_GRANULARITY is the amount we increase theta by
 * for each X location 
 * theta is in radians, hence the very small value */
#define X_GRANULARITY 0.25
#define THETA_GRANULARITY 0.005

/* we also need to know how many units to extend the line as we test it
 * this is done by setting the amount traveled along the line (which is the hypotenuse of a triangle */
#define HYP_GRANULARITY 0.25

typedef struct {
    double x1, y1, x2, y2;
    int hit;
} room;

/* checks whether a point is in a room */
int point_in_room(double x, double y, room r) {
    return x > r.x1 && x < r.x2 && y > r.y1 && y < r.y2;
}


/* this function checks one shot of the laser through the frigate */
int check_shot(room* rooms, int N, double xloc, double theta, double max_y) {
    /* get the dx and dy values that we use for the ray-tracing
     * yay for using trigonometry! */
    double dx = cos(theta) * HYP_GRANULARITY;
    double dy = sin(theta) * HYP_GRANULARITY;

    /* start at the beginning */
    double yloc = 0.0;

    /* mark all rooms as unhit */
    for (int i = 0; i < N; i++) {
        rooms[i].hit = 0;
    }

    /* keep going until one is out of range */
    while (xloc <= 100.0 && yloc <= max_y && xloc >= 0 && yloc >= 0) {
        /* check each room */
        for (int i = 0; i < N; i++) {
            if (point_in_room(xloc, yloc, rooms[i])) {
                rooms[i].hit = 1;
            }
        }

        /* move to the next point along the laser */
        xloc += dx;
        yloc += dy; 
    }

    /* count rooms we got */
    int hit = 0;
    for (int i = 0; i < N; i++) {
        if (rooms[i].hit) {
            hit++;
        }
    }

    return hit;
}

int main() {
    int N;
    scanf("%d\n", &N);
    room* rooms = malloc(N * sizeof(room));
    double max_x = 0.0, max_y = 0.0;
    for (int i = 0; i < N; i++) {
        /* read in the coordinates for this room */
        scanf("%lf %lf %lf %lf\n", &rooms[i].x1, &rooms[i].y1, &rooms[i].x2, &rooms[i].y2);

        /* adjust maximum values for the ship */
        if(rooms[i].x2 > max_x) {
            max_x = rooms[i].x2;
        }
        if (rooms[i].y2 > max_y) {
            max_y = rooms[i].y2;
        }
    }

    /* keep track of most rooms we have hit */
    int max = 0;

    /* loop through each X */
    for (double xloc = 0.0; xloc <= max_x; xloc += X_GRANULARITY) {
        /* loop through each angle */
        for (double theta = THETA_GRANULARITY; theta < (2 * M_PI); theta += THETA_GRANULARITY) {
            int amount = check_shot(rooms, N, xloc, theta, max_y);
            if (amount > max) {
                max = amount;
            }
        }
    }

    /* print the results */
    printf("We can hit %d room%s.\n", max, max == 1 ? "" : "s");
    return 0;
}

